@@ -13,25 +13,12 @@
 #include <KAboutData>
 #include <KCrash>
 #include <KDBusService>
-#if QT_VERSION < QT_VERSION_CHECK(6, 0, 0)
-#include <Kdelibs4ConfigMigrator>
-#endif
 #include <KLocalizedString>
 
 int main(int argc, char *argv[])
 {
     KGpgApp app(argc, argv);
-#if QT_VERSION < QT_VERSION_CHECK(6, 0, 0)
-    app.setAttribute(Qt::AA_UseHighDpiPixmaps, true);
-#endif
     KCrash::initialize();
-#if QT_VERSION < QT_VERSION_CHECK(6, 0, 0)
-    Kdelibs4ConfigMigrator migrate(QLatin1String("kgpg"));
-    migrate.setConfigFiles({ QLatin1String("kgpgrc") });
-    migrate.setUiFiles({ QStringLiteral("keysmanager.rc"), QStringLiteral("kgpgeditor.rc") });
-    migrate.migrate();
-#endif
-
     KLocalizedString::setApplicationDomain("kgpg");
 
     KAboutData about (
